==> hinemos_src-4.0.3.tar.gz: HinemosClient/src_calendar/com/clustercontrol/calendar/composite/action/VerticalBarSelectionListener.java <==
/*

Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.calendar.composite.action;

import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.IViewPart;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PlatformUI;

import com.clustercontrol.calendar.composite.CalendarListComposite;
import com.clustercontrol.calendar.composite.CalendarScheduleComposite;
import com.clustercontrol.calendar.view.CalendarListView;

/**
 * 垂直バーのSelectionListenerクラス<BR>
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class VerticalBarSelectionListener implements SelectionListener {
	protected Composite m_composite;

	/**
	 * コンストラクタ
	 * 
	 * @param composite
	 */
	public VerticalBarSelectionListener(Composite composite) {
		m_composite = composite;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.swt.events.SelectionListener#widgetSelected(org.eclipse.swt.events.SelectionEvent)
	 */
	@Override
	public void widgetSelected(SelectionEvent e) {
		//アクティブページを取得
		IWorkbenchPage page =
			PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage();

		if(m_composite instanceof CalendarListComposite){
			//ビューを取得
			IViewPart viewPart = page.findView(CalendarListView.ID);
			if (viewPart != null) {
				CalendarListView view =
					(CalendarListView)viewPart.getAdapter(
							CalendarListView.class);

				view.getScheduleComposite().getTable().setTopIndex(
						view.getListComposite().getTable().getTopIndex());
			}
		}
		else if(m_composite instanceof CalendarScheduleComposite){
			//ビューを取得
			IViewPart viewPart = page.findView(CalendarListView.ID);
			if (viewPart != null) {
				CalendarListView view =
					(CalendarListView)viewPart.getAdapter(
							CalendarListView.class);

				view.getListComposite().getTable().setTopIndex(
						view.getScheduleComposite().getTable().getTopIndex());
			}
		}
	}

	/* (non-Javadoc)
	 * @see org.eclipse.swt.events.SelectionListener#widgetDefaultSelected(org.eclipse.swt.events.SelectionEvent)
	 */
	@Override
	public void widgetDefaultSelected(SelectionEvent e) {

	}
}

==> hinemos_src-4.1.3.tar.gz: HinemosClient/src_calendar/com/clustercontrol/calendar/composite/action/VerticalBarSelectionListener.java <==
/*

Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.calendar.composite.action;

import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.IViewPart;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PlatformUI;

import com.clustercontrol.calendar.composite.CalendarPatternComposite;
import com.clustercontrol.calendar.composite.CalendarListComposite;
import com.clustercontrol.calendar.view.CalendarPatternView;
import com.clustercontrol.calendar.view.CalendarListView;

/**
 * 垂直バーのSelectionListenerクラス<BR>
 * 
 * @version 4.1.0
 * @since 2.0.0
 */
public class VerticalBarSelectionListener implements SelectionListener {
	private Composite m_composite;

	/**
	 * コンストラクタ
	 * 
	 * @param composite
	 */
	public VerticalBarSelectionListener(Composite composite) {
		m_composite = composite;
	}

	/* (non-Javadoc)
	 * @see org.eclipse.swt.events.SelectionListener#widgetSelected(org.eclipse.swt.events.SelectionEvent)
	 */
	@Override
	public void widgetSelected(SelectionEvent e) {
		//アクティブページを取得
		IWorkbenchPage page =
				PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage();
		//カレンダ[一覧]ビュー
		if(m_composite instanceof CalendarListComposite){
			//ビューを取得
			IViewPart viewPart = page.findView(CalendarListView.ID);
			if (viewPart != null) {
				CalendarListView view = (CalendarListView)viewPart
						.getAdapter(CalendarListView.class);
			}
		}
		//カレンダ[カレンダパターン]ビュー
		else if(m_composite instanceof CalendarPatternComposite){
			//ビューを取得
			IViewPart viewPart = page.findView(CalendarListView.ID);
			if (viewPart != null) {
				CalendarPatternView view = (CalendarPatternView)viewPart
						.getAdapter(CalendarPatternView.class);
			}
		}
	}

	/* (non-Javadoc)
	 * @see org.eclipse.swt.events.SelectionListener#widgetDefaultSelected(org.eclipse.swt.events.SelectionEvent)
	 */
	@Override
	public void widgetDefaultSelected(SelectionEvent e) {

	}
}
